#ifndef %{APPNAME}_MENU_APPLET_H
#define %{APPNAME}_MENU_APPLET_H

#include <tqpe/menuappletinterface.h>

#include <tqobject.h>

class %{APPNAME} : public TQObject, public MenuAppletInterface
{

    Q_OBJECT
  TQ_OBJECT

public:
    %{APPNAME} ( );
    virtual ~%{APPNAME} ( );

    TQRESULT queryInterface( const TQUuid&, TQUnknownInterface** );
    TQ_REFCOUNT

    virtual int position() const;
    
    virtual TQString name ( ) const;
    virtual TQIconSet icon ( ) const;
    virtual TQString text ( ) const;
    /* virtual TQString tr( const char* ) const;
    virtual TQString tr( const char*, const char* ) const;
    */
    virtual TQPopupMenu *popup ( TQWidget *parent ) const;
    virtual void activated ( );
};

#endif
